import unittest
from pyvalidator import *

class TestIsInt(unittest.TestCase):

    def test_valid_ints(self):
        self.assertTrue(is_int('13'))
        self.assertTrue(is_int('123'))
        self.assertTrue(is_int('0'))
        self.assertTrue(is_int('-0'))
        self.assertTrue(is_int('+1'))
        self.assertTrue(is_int('01'))
        self.assertTrue(is_int('-01'))
        self.assertTrue(is_int('000'))
        print('OK - test_valid_ints')

    def test_invalid_ints(self):
        self.assertFalse(is_int('100e10'))
        self.assertFalse(is_int('123.123'))
        self.assertFalse(is_int('   '))
        self.assertFalse(is_int(''))
        self.assertFalse(is_int('.'))
        self.assertFalse(is_int('foo'))
        print('OK - test_invalid_ints')

    def test_valid_ints_dont_allow_leading_zeroes(self) -> bool:
        self.assertTrue(is_int('13', { "allow_leading_zeroes": False }))
        self.assertTrue(is_int('11', { "allow_leading_zeroes": False }))
        self.assertTrue(is_int('123', { "allow_leading_zeroes": False }))
        self.assertTrue(is_int('0', { "allow_leading_zeroes": False }))
        self.assertTrue(is_int('-0', { "allow_leading_zeroes": False }))
        self.assertTrue(is_int('+1', { "allow_leading_zeroes": False }))
        print('OK - test_valid_ints_dont_allow_leading_zeroes')

    def test_invalid_ints_dont_allow_leading_zeroes(self):
        self.assertFalse(is_int('01', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('-01', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('000', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('100e10', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('123.11', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('foo', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('   ', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('\n', { "allow_leading_zeroes": False }))
        self.assertFalse(is_int('\t', { "allow_leading_zeroes": False }))
        print('OK - test_invalid_ints_dont_allow_leading_zeroes')

    def test_fail_ints(self):
        self.assertRaises(Exception, is_int, None)
        self.assertRaises(Exception, is_int, {})



import unittest
from pyvalidator import *

class TestIsEmail(unittest.TestCase):

    def test_valid_email(self):
        self.assertTrue(is_email('foo@bar.com'))
        self.assertTrue(is_email('x@x.au'))
        self.assertTrue(is_email('foo@bar.com.au'))
        self.assertTrue(is_email('foo+bar@bar.com'))
        self.assertTrue(is_email('hans.m端ller@test.com'))
        self.assertTrue(is_email('hans@m端ller.com'))
        self.assertTrue(is_email('test|123@m端ller.com'))
        self.assertTrue(is_email('test123+ext@gmail.com'))
        self.assertTrue(is_email('some.name.midd.leNa.me.and.locality+extension@GoogleMail.com'))
        self.assertTrue(is_email('"foobar"@example.com'))
        self.assertTrue(is_email('"  foo  m端ller "@example.com'))
        self.assertTrue(is_email('"foo\\@bar"@example.com'))
        self.assertTrue(is_email("{}@{}.com".format(('a' * 64), ('a' * 63))))
        self.assertTrue(is_email("{}@{}.com".format(('a' * 64), ('a' * 63))))
        self.assertTrue(is_email("{}@gmail.com".format(('a' * 31))))
        self.assertTrue(is_email('test@gmail.com'))
        self.assertTrue(is_email('test.1@gmail.com'))
        self.assertTrue(is_email('test@1337.com'))
        print('OK - test_valid_email')

    def test_invalid_email(self):
        self.assertFalse(is_email('invalidemail@'))
        self.assertFalse(is_email('invalid.com'))
        self.assertFalse(is_email('@invalid.com'))
        self.assertFalse(is_email('foo@bar.com.'))
        self.assertFalse(is_email('somename@ｇｍａｉｌ.com'))
        self.assertFalse(is_email('foo@bar.co.uk.'))
        self.assertFalse(is_email('z@co.c'))
        self.assertFalse(is_email('ｇｍａｉｌｇｍａｉｌｇｍａｉｌｇｍａｉｌｇｍａｉｌ@gmail.com'))
        self.assertFalse(is_email("{}@{}.com".format('a' * 64, 'a' * 251)))
        self.assertFalse(is_email("{}@{}.com".format('a' * 65, 'a' * 250)))
        self.assertFalse(is_email("{}@{}.com".format('a' * 64, 'a' * 64)))
        self.assertFalse(is_email("{}@{}.{}.{}.{}.com".format('a' * 64, 'b' * 63, 'b' * 63, 'c' * 63, 'd' * 58)))
        self.assertFalse(is_email('test1@invalid.co m'))
        self.assertFalse(is_email('test2@invalid.co m'))
        self.assertFalse(is_email('test3@invalid.co m'))
        self.assertFalse(is_email('test4@invalid.co m'))
        self.assertFalse(is_email('test5@invalid.co m'))
        self.assertFalse(is_email('test6@invalid.co m'))
        self.assertFalse(is_email('test7@invalid.co m'))
        self.assertFalse(is_email('test8@invalid.co m'))
        self.assertFalse(is_email('test9@invalid.co m'))
        self.assertFalse(is_email('test10@invalid.co m'))
        self.assertFalse(is_email('test11@invalid.co m'))
        self.assertFalse(is_email('test12@invalid.co　m'))
        self.assertFalse(is_email('test13@invalid.co　m'))
        self.assertFalse(is_email('multiple..dots@stillinvalid.com'))
        self.assertFalse(is_email('test123+invalid! sub_address@gmail.com'))
        self.assertFalse(is_email('gmail...ignores...dots...@gmail.com'))
        self.assertFalse(is_email('ends.with.dot.@gmail.com'))
        self.assertFalse(is_email('multiple..dots@gmail.com'))
        self.assertFalse(is_email('wrong()[]",:;<>@@gmail.com'))
        self.assertFalse(is_email('"wrong()[]",:;<>@@gmail.com'))
        self.assertFalse(is_email('username@domain.com�'))
        self.assertFalse(is_email('username@domain.com©'))
        print('OK - test_invalid_email')

    def test_valid_domain_specific_email(self):
        self.assertTrue(is_email('foobar@gmail.com', { "domain_specific_validation": True }))
        self.assertTrue(is_email('foo.bar@gmail.com', { "domain_specific_validation": True }))
        self.assertTrue(is_email('foo.bar@googlemail.com', { "domain_specific_validation": True }))
        self.assertTrue(is_email('{}@gmail.com'.format('a' * 30), { "domain_specific_validation": True }))
        print('OK - test_valid_domain_specific_email')

    def test_invalid_domain_specific_email(self):
        self.assertFalse(is_email('test.1@gmail.com', { "domain_specific_validation": True }))
        self.assertFalse(is_email('.foobar@gmail.com', { "domain_specific_validation": True }))
        self.assertFalse(is_email("{}@gmail.com".format('s' * 31), { "domain_specific_validation": True }))
        print('OK - test_invalid_domain_specific_email')

    def test_valid_email_with_utf8_char_in_local_part(self):
        self.assertTrue(is_email('foo@bar.com', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('x@x.au', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('foo@bar.com.au', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('foo+bar@bar.com', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('hans@m端ller.com', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('test|123@m端ller.com', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('test123+ext@gmail.com', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('some.name.midd.leNa.me+extension@GoogleMail.com', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('"foobar"@example.com', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('"foo\\@bar"@example.com', { "allow_utf8_local_part": False }))
        self.assertTrue(is_email('"  foo  bar  "@example.com', { "allow_utf8_local_part": False }))
        print('OK - test_valid_email_with_utf8_char_in_local_part')

    def test_invalid_email_with_utf8_char_in_local_part(self):
        self.assertFalse(is_email('invalidemail@', { "allow_utf8_local_part": False }))
        self.assertFalse(is_email('invalid.com', { "allow_utf8_local_part": False }))
        self.assertFalse(is_email('@invalid.com', { "allow_utf8_local_part": False }))
        self.assertFalse(is_email('foo@bar.com.', { "allow_utf8_local_part": False }))
        self.assertFalse(is_email('foo@bar.co.uk.', { "allow_utf8_local_part": False }))
        self.assertFalse(is_email('somename@ｇｍａｉｌ.com', { "allow_utf8_local_part": False }))
        self.assertFalse(is_email('hans.m端ller@test.com', { "allow_utf8_local_part": False }))
        self.assertFalse(is_email('z@co.c', { "allow_utf8_local_part": False }))
        self.assertFalse(is_email('tüst@invalid.com', { "allow_utf8_local_part": False }))
        print('OK - test_invalid_email_with_utf8_char_in_local_part')

    def test_valid_email_with_display_name(self):
        self.assertTrue(is_email('foo@bar.com', { "allow_display_name": True }))
        self.assertTrue(is_email('x@x.au', { "allow_display_name": True }))
        self.assertTrue(is_email('foo@bar.com.au', { "allow_display_name": True }))
        self.assertTrue(is_email('foo+bar@bar.com', { "allow_display_name": True }))
        self.assertTrue(is_email('hans.m端ller@test.com', { "allow_display_name": True }))
        self.assertTrue(is_email('hans@m端ller.com', { "allow_display_name": True }))
        self.assertTrue(is_email('test|123@m端ller.com', { "allow_display_name": True }))
        self.assertTrue(is_email('test123+ext@gmail.com', { "allow_display_name": True }))
        self.assertTrue(is_email('some.name.midd.leNa.me+extension@GoogleMail.com', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <foo@bar.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <x@x.au>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <foo@bar.com.au>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <foo+bar@bar.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <hans.m端ller@test.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <hans@m端ller.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <test|123@m端ller.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <test123+ext@gmail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('\'Foo Bar, Esq\'<foo@bar.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <some.name.midd.leNa.me+extension@GoogleMail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Middle Name <some.name.midd.leNa.me+extension@GoogleMail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Name <some.name.midd.leNa.me+extension@GoogleMail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Name<some.name.midd.leNa.me+extension@GoogleMail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Some Name <foo@gmail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('Name🍓With🍑Emoji🚴‍♀️🏆<test@aftership.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('🍇🍗🍑<only_emoji@aftership.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('"<displayNameInBrackets>"<jh@gmail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('"\\"quotes\\""<jh@gmail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('"name;"<jh@gmail.com>', { "allow_display_name": True }))
        self.assertTrue(is_email('"name;" <jh@gmail.com>', { "allow_display_name": True }))
        print('OK - test_valid_email_with_display_name')

    def test_invalid_email_with_display_name(self):
        self.assertFalse(is_email('invalidemail@', { "allow_display_name": True }))
        self.assertFalse(is_email('invalid.com', { "allow_display_name": True }))
        self.assertFalse(is_email('@invalid.com', { "allow_display_name": True }))
        self.assertFalse(is_email('foo@bar.com.', { "allow_display_name": True }))
        self.assertFalse(is_email('foo@bar.co.uk.', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name <invalidemail@>', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name <invalid.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name <@invalid.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name <foo@bar.com.>', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name <foo@bar.co.uk.>', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name foo@bar.co.uk.>', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name <foo@bar.co.uk.', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name < foo@bar.co.uk >', { "allow_display_name": True }))
        self.assertFalse(is_email('Name foo@bar.co.uk', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name <some..name@gmail.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('Some Name<emoji_in_address🍈@aftership.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('invisibleCharacter\u001F<jh@gmail.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('<displayNameInBrackets><jh@gmail.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('\\"quotes\\"<jh@gmail.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('""quotes""<jh@gmail.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('name;<jh@gmail.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('    <jh@gmail.com>', { "allow_display_name": True }))
        self.assertFalse(is_email('"    "<jh@gmail.com>', { "allow_display_name": True }))
        print('OK - test_invalid_email_with_display_name')

    def test_valid_email_with_required_display_name(self):
        self.assertTrue(is_email('Some Name <foo@bar.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Name <x@x.au>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Name <foo@bar.com.au>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Name <foo+bar@bar.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Name <hans.m端ller@test.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Name <hans@m端ller.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Name <test|123@m端ller.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Name <test123+ext@gmail.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Name <some.name.midd.leNa.me+extension@GoogleMail.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Some Middle Name <some.name.midd.leNa.me+extension@GoogleMail.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Name <some.name.midd.leNa.me+extension@GoogleMail.com>', { "require_display_name": True }))
        self.assertTrue(is_email('Name<some.name.midd.leNa.me+extension@GoogleMail.com>', { "require_display_name": True }))
        print('OK - test_valid_email_with_required_display_name')

    def test_invalid_email_with_required_display_name(self):
        self.assertFalse(is_email('some.name.midd.leNa.me+extension@GoogleMail.com', { "require_display_name": True }))
        self.assertFalse(is_email('foo@bar.com', { "require_display_name": True }))
        self.assertFalse(is_email('x@x.au', { "require_display_name": True }))
        self.assertFalse(is_email('foo@bar.com.au', { "require_display_name": True }))
        self.assertFalse(is_email('foo+bar@bar.com', { "require_display_name": True }))
        self.assertFalse(is_email('hans.m端ller@test.com', { "require_display_name": True }))
        self.assertFalse(is_email('hans@m端ller.com', { "require_display_name": True }))
        self.assertFalse(is_email('test|123@m端ller.com', { "require_display_name": True }))
        self.assertFalse(is_email('test123+ext@gmail.com', { "require_display_name": True }))
        self.assertFalse(is_email('invalidemail@', { "require_display_name": True }))
        self.assertFalse(is_email('invalid.com', { "require_display_name": True }))
        self.assertFalse(is_email('@invalid.com', { "require_display_name": True }))
        self.assertFalse(is_email('foo@bar.com.', { "require_display_name": True }))
        self.assertFalse(is_email('foo@bar.co.uk.', { "require_display_name": True }))
        self.assertFalse(is_email('Some Name <invalidemail@>', { "require_display_name": True }))
        self.assertFalse(is_email('Some Name <invalid.com>', { "require_display_name": True }))
        self.assertFalse(is_email('Some Name <@invalid.com>', { "require_display_name": True }))
        self.assertFalse(is_email('Some Name <foo@bar.com.>', { "require_display_name": True }))
        self.assertFalse(is_email('Some Name <foo@bar.co.uk.>', { "require_display_name": True }))
        self.assertFalse(is_email('Some Name foo@bar.co.uk.>', { "require_display_name": True }))
        self.assertFalse(is_email('Some Name <foo@bar.co.uk.', { "require_display_name": True }))
        self.assertFalse(is_email('Some Name < foo@bar.co.uk >', { "require_display_name": True }))
        self.assertFalse(is_email('Name foo@bar.co.uk', { "require_display_name": True }))
        print('OK - test_invalid_email_with_required_display_name')

    def test_valid_emails_with_ip(self):
        self.assertTrue(is_email('email@[123.123.123.123]', { "allow_ip_domain": True }))
        self.assertTrue(is_email('email@255.255.255.255', { "allow_ip_domain": True }))
        print('OK - test_valid_emails_with_ip')

    def test_invalid_emails_with_ip(self):
        self.assertFalse(is_email('email@0.0.0.256', { "allow_ip_domain": True }))
        self.assertFalse(is_email('email@26.0.0.256', { "allow_ip_domain": True }))
        self.assertFalse(is_email('email@[266.266.266.266]', { "allow_ip_domain": True }))
        print('OK - test_invalid_emails_with_ip')

    def test_valid_emails_with_blacklisted_chars_in_name(self):
        self.assertTrue(is_email('emil@gmail.com', { "blacklisted_chars": 'abc' }))
        self.assertTrue(is_email('ssss@gmail.com', { "blacklisted_chars": 'abc' }))
        self.assertFalse(is_email('today@yahoo.com', { "blacklisted_chars": 'time' }))
        print('OK - test_valid_emails_with_blacklisted_chars_in_name')

    def test_invalid_emails_with_blacklisted_chars_in_name(self):
        self.assertFalse(is_email('email@gmail.com', { "blacklisted_chars": 'abc' }))
        self.assertFalse(is_email('ssss@gmail.com', { "blacklisted_chars": 's' }))
        self.assertFalse(is_email('ssss@gmail.com', { "blacklisted_chars": 'ssss' }))
        self.assertFalse(is_email('today@yahoo.com', { "blacklisted_chars": 'day' }))
        print('OK - test_invalid_emails_with_blacklisted_chars_in_name')

    def test_valid_long_emails(self):
        self.assertTrue(is_email('Deleted-user-id-19430-Team-5051deleted-user-id-19430-team-5051XXXXXX@example.com', { "ignore_max_length": True }))
        print('OK - test_valid_long_emails')

    def test_invalid_long_emails(self):
        self.assertFalse(is_email('Deleted-user-id-19430-Team-5051deleted-user-id-19430-team-5051XXXXXX@example.com', { "ignore_max_length": False }))
        self.assertFalse(is_email('Deleted-user-id-19430-Team-5051deleted-user-id-19430-team-5051XXXXXX-blablabla-blablabla-blablabla-blablabla-blablabla-blablabla@example.com', { "ignore_max_length": False }))
        print('OK - test_invalid_long_emails')

    def test_valid_emails_with_denied_domains(self):
        self.assertTrue(is_email('sample@test.com', { "host_blacklist": ['web.com', 'test.domain.com'] }))
        self.assertTrue(is_email('sample@domain.com', { "host_blacklist": ['web.com', 'test.domain.com'] }))
        print('OK - test_valid_emails_with_denied_domains')

    def test_invalid_emails_with_denied_domains(self):
        self.assertFalse(is_email('gosn@web.com', { "host_blacklist": ['web.com', 'test.domain.com'] }))
        self.assertFalse(is_email('gosn@test.domain.com', { "host_blacklist": ['web.com', 'test.domain.com'] }))
        print('OK - test_invalid_emails_with_denied_domains')



import unittest
from pyvalidator import *

class TestIsPassportNumber(unittest.TestCase):

    def test_valid_passport_number(self):
        self.assertTrue(is_passport_number('AF0549358', "AM"))
        self.assertTrue(is_passport_number('C1253473', "ID"))
        self.assertTrue(is_passport_number('B5948378', "ID"))
        self.assertTrue(is_passport_number('A4859472', "ID"))
        self.assertTrue(is_passport_number('AAC811035', "AR"))
        self.assertTrue(is_passport_number('P 1630837', "AT"))
        self.assertTrue(is_passport_number('P 4366918', "AT"))
        self.assertTrue(is_passport_number('N0995852', "AU"))
        self.assertTrue(is_passport_number('L4819236', "AU"))
        self.assertTrue(is_passport_number('A1234567', "BA"))
        self.assertTrue(is_passport_number('346395366', "BG"))
        self.assertTrue(is_passport_number('039903356', "BG"))
        self.assertTrue(is_passport_number('FZ973689', "BR"))
        self.assertTrue(is_passport_number('GH231233', "BR"))
        self.assertTrue(is_passport_number('MP3899901', "BY"))
        self.assertTrue(is_passport_number('GA302922', "CA"))
        self.assertTrue(is_passport_number('S1100409', "CH"))
        self.assertTrue(is_passport_number('X4028791', "CH"))
        self.assertTrue(is_passport_number('E00160027', "CN"))
        self.assertTrue(is_passport_number('EA1234567', "CN"))
        self.assertTrue(is_passport_number('K00000413', "CY"))
        self.assertTrue(is_passport_number('99003853', "CZ"))
        self.assertTrue(is_passport_number('42747260', "CZ"))
        self.assertTrue(is_passport_number('C01X00T47', "DE"))
        self.assertTrue(is_passport_number('900010172', "DK"))
        self.assertTrue(is_passport_number('855609385', "DZ"))
        self.assertTrue(is_passport_number('K4218285', "EE"))
        self.assertTrue(is_passport_number('KB0167630', "EE"))
        self.assertTrue(is_passport_number('AF238143', "ES"))
        self.assertTrue(is_passport_number('XP8271602', "FI"))
        self.assertTrue(is_passport_number('XD8500003', "FI"))
        self.assertTrue(is_passport_number('10CV28144', "FR"))
        self.assertTrue(is_passport_number('05RP34083', "FR"))
        self.assertTrue(is_passport_number('925076473', "GB"))
        self.assertTrue(is_passport_number('107182890', "GB"))
        self.assertTrue(is_passport_number('104121156', "GB"))
        self.assertTrue(is_passport_number('AE0000005', "GR"))
        self.assertTrue(is_passport_number('AK0219304', "GR"))
        self.assertTrue(is_passport_number('007007007', "HR"))
        self.assertTrue(is_passport_number('ZA084505', "HU"))
        self.assertTrue(is_passport_number('D23145890', "IE"))
        self.assertTrue(is_passport_number('X65097105', "IE"))
        self.assertTrue(is_passport_number('X0019390', "IN"))
        self.assertTrue(is_passport_number('A-1234567', "IN"))
        self.assertTrue(is_passport_number('J97634522', "IR"))
        self.assertTrue(is_passport_number('A01234567', "IR"))
        self.assertTrue(is_passport_number('A1197783', "IS"))
        self.assertTrue(is_passport_number('A2040611', "IS"))
        self.assertTrue(is_passport_number('YA8335453', "IT"))
        self.assertTrue(is_passport_number('KK0000000', "IT"))
        self.assertTrue(is_passport_number('NH1106002', "JP"))
        self.assertTrue(is_passport_number('TE3180251', "JP"))
        self.assertTrue(is_passport_number('XS1234567', "JP"))
        self.assertTrue(is_passport_number('M35772699', "KR"))
        self.assertTrue(is_passport_number('20200997', "LT"))
        self.assertTrue(is_passport_number('LB311756', "LT"))
        self.assertTrue(is_passport_number('JCU9J4T2', "LU"))
        self.assertTrue(is_passport_number('LV9000339', "LV"))
        self.assertTrue(is_passport_number('LV4017173', "LV"))
        self.assertTrue(is_passport_number('RJ45H4V2', "LY"))
        self.assertTrue(is_passport_number('1026564', "MT"))
        self.assertTrue(is_passport_number('AB0808212', "MZ"))
        self.assertTrue(is_passport_number('08AB12123', "MZ"))
        self.assertTrue(is_passport_number('A00000000', "MY"))
        self.assertTrue(is_passport_number('H12345678', "MY"))
        self.assertTrue(is_passport_number('XTR110131', "NL"))
        self.assertTrue(is_passport_number('XR1001R58', "NL"))
        self.assertTrue(is_passport_number('ZS 0000177', "PL"))
        self.assertTrue(is_passport_number('AN 3000011', "PL"))
        self.assertTrue(is_passport_number('I700044', "PT"))
        self.assertTrue(is_passport_number('K453286', "PT"))
        self.assertTrue(is_passport_number('05485968', "RO"))
        self.assertTrue(is_passport_number('040005646', "RO"))
        self.assertTrue(is_passport_number('014213789', "RS"))
        self.assertTrue(is_passport_number('2 32 636829', "RU"))
        self.assertTrue(is_passport_number('012 345321', "RU"))
        self.assertTrue(is_passport_number('59000001', "SE"))
        self.assertTrue(is_passport_number('PB0036440', "SL"))
        self.assertTrue(is_passport_number('P0000000', "SK"))
        self.assertTrue(is_passport_number('U 06764100', "TR"))
        self.assertTrue(is_passport_number('EH345655', "UA"))
        self.assertTrue(is_passport_number('AP841503', "UA"))
        self.assertTrue(is_passport_number('790369937', "US"))
        self.assertTrue(is_passport_number('340007237', "US"))
        print('OK - test_valid_passport_number')

    def test_invalid_passport_number(self):
        self.assertFalse(is_passport_number('A1054935', "AM"))
        self.assertFalse(is_passport_number('D39481728', "ID"))
        self.assertFalse(is_passport_number('A-3847362', "ID"))
        self.assertFalse(is_passport_number('324132132', "ID"))
        self.assertFalse(is_passport_number('A11811035', "AR"))
        self.assertFalse(is_passport_number('0 1630837', "AT"))
        self.assertFalse(is_passport_number('1A012345', "AU"))
        self.assertFalse(is_passport_number('ABC123456', "BA"))
        self.assertFalse(is_passport_number('ABC123456', "BG"))
        self.assertFalse(is_passport_number('ABX29332', "BR"))
        self.assertFalse(is_passport_number('345333454', "BY"))
        self.assertFalse(is_passport_number('FG53334542', "BY"))
        self.assertFalse(is_passport_number('AB0123456', "CA"))
        self.assertFalse(is_passport_number('AB123456', "CH"))
        self.assertFalse(is_passport_number('E-1234567', "CN"))
        self.assertFalse(is_passport_number('GO1234567', "CN"))
        self.assertFalse(is_passport_number('K10100', "CY"))
        self.assertFalse(is_passport_number('012345678', "CZ"))
        self.assertFalse(is_passport_number('AB123456', "CZ"))
        self.assertFalse(is_passport_number('A012345678', "DE"))
        self.assertFalse(is_passport_number('AS0123456', "DZ"))
        self.assertFalse(is_passport_number('K01234567', "EE"))
        self.assertFalse(is_passport_number('AF01234567', "ES"))
        self.assertFalse(is_passport_number('ABC012345', "FI"))
        self.assertFalse(is_passport_number('A01234567', "FI"))
        self.assertFalse(is_passport_number('012345678', "FR"))
        self.assertFalse(is_passport_number('AB0123456', "FR"))
        self.assertFalse(is_passport_number('A012345678', "GB"))
        self.assertFalse(is_passport_number('K000000000', "GB"))
        self.assertFalse(is_passport_number('A01234567', "GR"))
        self.assertFalse(is_passport_number('A01234567', "HR"))
        self.assertFalse(is_passport_number('A01234567', "HU"))
        self.assertFalse(is_passport_number('012345678', "HU"))
        self.assertFalse(is_passport_number('XND012345', "IE"))
        self.assertFalse(is_passport_number('AB-1234567', "IN"))
        self.assertFalse(is_passport_number('0123456789', "IN"))
        self.assertFalse(is_passport_number('0123456789', "IN"))
        self.assertFalse(is_passport_number('A0123456', "IR"))
        self.assertFalse(is_passport_number('A0123456Z', "IR"))
        self.assertFalse(is_passport_number('K0000000', "IS"))
        self.assertFalse(is_passport_number('01234567', "IS"))
        self.assertFalse(is_passport_number('01234567', "IT"))
        self.assertFalse(is_passport_number('X12345678', "JP"))
        self.assertFalse(is_passport_number('012345678', "JP"))
        self.assertFalse(is_passport_number('X12345678', "KR"))
        self.assertFalse(is_passport_number('LB01234567', "LT"))
        self.assertFalse(is_passport_number('JCU9J4T', "LU"))
        self.assertFalse(is_passport_number('LV01234567', "LV"))
        self.assertFalse(is_passport_number('4017173LV', "LV"))
        self.assertFalse(is_passport_number('P79JF34', "LY"))
        self.assertFalse(is_passport_number('MT01234', "MT"))
        self.assertFalse(is_passport_number('1AB011241', "MZ"))
        self.assertFalse(is_passport_number('ABAB01121', "MZ"))
        self.assertFalse(is_passport_number('A1234567', "MY"))
        self.assertFalse(is_passport_number('C01234567', "MY"))
        self.assertFalse(is_passport_number('XTR11013R', "NL"))
        self.assertFalse(is_passport_number('A1 0000177', "PL"))
        self.assertFalse(is_passport_number('K4532861', "PT"))
        self.assertFalse(is_passport_number('0511060461', "RO"))
        self.assertFalse(is_passport_number('R05485968', "RO"))
        self.assertFalse(is_passport_number('01A 3D5321', "RS"))
        self.assertFalse(is_passport_number('01A 3D5321', "RU"))
        self.assertFalse(is_passport_number('A 2R YU46J0', "RU"))
        self.assertFalse(is_passport_number('SE012345', "SE"))
        self.assertFalse(is_passport_number('SL0123456', "SL"))
        self.assertFalse(is_passport_number('SK012345', "SK"))
        self.assertFalse(is_passport_number('06764100U', "TR"))
        self.assertFalse(is_passport_number('01234567', "UA"))
        self.assertFalse(is_passport_number('012345EH', "UA"))
        self.assertFalse(is_passport_number('A012345P', "UA"))
        self.assertFalse(is_passport_number('US0123456', "US"))
        self.assertFalse(is_passport_number('US0123456', "US"))
        self.assertFalse(is_passport_number('7903699371', "US"))
        print('OK - test_invalid_passport_number')



import unittest
from pyvalidator import *

class TestIsJson(unittest.TestCase):

    def test_valid_json(self):
        self.assertTrue(is_json('{ "key": "value" }'))
        self.assertTrue(is_json('{}'))
        print('OK - test_valid_json')

    def test_invalid_json(self):
        self.assertFalse(is_json('{ key: "value" }'))
        self.assertFalse(is_json('{ \'key\': \'value\' }'))
        self.assertFalse(is_json('null'))
        self.assertFalse(is_json('1234'))
        self.assertFalse(is_json('11.1'))
        self.assertFalse(is_json('nope'))
        self.assertFalse(is_json('None'))
        self.assertFalse(is_json('false'))
        self.assertFalse(is_json('true'))
        print('OK - test_invalid_json')

    def test_valid_json_allow_primitives(self):
        self.assertTrue(is_json('{ "key": "value" }', { "allow_primitives": True }))
        self.assertTrue(is_json('{}', { "allow_primitives": True }))
        self.assertTrue(is_json('false', { "allow_primitives": True }))
        self.assertTrue(is_json('true', { "allow_primitives": True }))
        print('OK - test_valid_json_allow_primitives')

    def test_invalid_json_allow_primitives(self):
        self.assertFalse(is_json('{ key: "value" }', { "allow_primitives": True }))
        self.assertFalse(is_json('{ \'key\': \'value\' }', { "allow_primitives": True }))
        self.assertFalse(is_json('{ "key": value }', { "allow_primitives": True }))
        self.assertFalse(is_json('1234', { "allow_primitives": True }))
        self.assertFalse(is_json('nope', { "allow_primitives": True }))
        self.assertFalse(is_json('None', { "allow_primitives": True }))
        print('OK - test_invalid_json_allow_primitives')



from .utils.assert_string import assert_string
from .utils.Classes.RegEx import RegEx

base58Reg = RegEx("^[A-HJ-NP-Za-km-z1-9]*$")

def is_base58(input: str) -> bool:
    input = assert_string(input)
    return base58Reg.match(input)



import unittest
from pyvalidator import *

class TestIsPort(unittest.TestCase):

    def test_valid_port(self):
        self.assertTrue(is_port('0'))
        self.assertTrue(is_port('22'))
        self.assertTrue(is_port('80'))
        self.assertTrue(is_port('443'))
        self.assertTrue(is_port('5000'))
        self.assertTrue(is_port('8000'))
        self.assertTrue(is_port('65535'))
        print('OK - test_valid_port')

    def test_invalid_port(self):
        self.assertFalse(is_port(''))
        self.assertFalse(is_port('-1'))
        self.assertFalse(is_port('65536'))
        self.assertFalse(is_port('655369'))
        self.assertFalse(is_port('.'))
        print('OK - test_invalid_port')



import unittest
from pyvalidator import *

class TestIsIpRange(unittest.TestCase):

    def test_valid_ip_range(self):
        self.assertTrue(is_ip_range('127.0.0.1/24'))
        self.assertTrue(is_ip_range('0.0.0.0/0'))
        self.assertTrue(is_ip_range('255.255.255.0/32'))
        self.assertTrue(is_ip_range('::/0'))
        self.assertTrue(is_ip_range('::/128'))
        self.assertTrue(is_ip_range('2001::/128'))
        self.assertTrue(is_ip_range('2001:800::/128'))
        self.assertTrue(is_ip_range('::ffff:127.0.0.1/128'))
        print('OK - test_valid_ip_range')

    def test_invalid_ip_range(self):
        self.assertFalse(is_ip_range('abc'))
        self.assertFalse(is_ip_range('127.200.230.1/35'))
        self.assertFalse(is_ip_range('127.200.230.1/-1'))
        self.assertFalse(is_ip_range('1.1.1.1/011'))
        self.assertFalse(is_ip_range('1.1.1/24.1'))
        self.assertFalse(is_ip_range('1.1.1.1/01'))
        self.assertFalse(is_ip_range('1.1.1.1/1.1'))
        self.assertFalse(is_ip_range('1.1.1.1/1.'))
        self.assertFalse(is_ip_range('1.1.1.1/1/1'))
        self.assertFalse(is_ip_range('1.1.1.1'))
        self.assertFalse(is_ip_range('::1'))
        self.assertFalse(is_ip_range('::1/164'))
        self.assertFalse(is_ip_range('2001::/240'))
        self.assertFalse(is_ip_range('2001::/-1'))
        self.assertFalse(is_ip_range('2001::/001'))
        self.assertFalse(is_ip_range('2001::/24.1'))
        self.assertFalse(is_ip_range('2001:db8:0000:1:1:1:1:1'))
        self.assertFalse(is_ip_range('::ffff:127.0.0.1'))
        print('OK - test_invalid_ip_range')

    def test_valid_ip_range_v4(self):
        self.assertTrue(is_ip_range('127.0.0.1/1', 4))
        self.assertTrue(is_ip_range('0.0.0.0/1', 4))
        self.assertTrue(is_ip_range('255.255.255.255/1', 4))
        self.assertTrue(is_ip_range('1.2.3.4/1', 4))
        self.assertTrue(is_ip_range('255.0.0.1/1', 4))
        self.assertTrue(is_ip_range('0.0.1.1/1', 4))
        print('OK - test_valid_ip_range_v4')

    def test_invalid_ip_range_v4(self):
        self.assertFalse(is_ip_range('abc', 4))
        self.assertFalse(is_ip_range('::1', 4))
        self.assertFalse(is_ip_range('2001:db8:0000:1:1:1:1:1', 4))
        self.assertFalse(is_ip_range('::ffff:127.0.0.1', 4))
        self.assertFalse(is_ip_range('137.132.10.01', 4))
        self.assertFalse(is_ip_range('0.256.0.256', 4))
        self.assertFalse(is_ip_range('255.256.255.256', 4))
        print('OK - test_invalid_ip_range_v4')

    def test_valid_ip_range_v6(self):
        self.assertTrue(is_ip_range('::1/1', 6))
        self.assertTrue(is_ip_range('2001:db8:0000:1:1:1:1:1/1', 6))
        self.assertTrue(is_ip_range('::ffff:127.0.0.1/1', 6))
        print('OK - test_valid_ip_range_v6')

    def test_invalid_ip_range_v6(self):
        self.assertFalse(is_ip_range('abc', 6))
        self.assertFalse(is_ip_range('127.0.0.1', 6))
        self.assertFalse(is_ip_range('0.0.0.0', 6))
        self.assertFalse(is_ip_range('255.255.255.255', 6))
        self.assertFalse(is_ip_range('1.2.3.4', 6))
        self.assertFalse(is_ip_range('::ffff:287.0.0.1', 6))
        self.assertFalse(is_ip_range('::ffff:287.0.0.1/254', 6))
        self.assertFalse(is_ip_range('%', 6))
        self.assertFalse(is_ip_range('fe80::1234%', 6))
        self.assertFalse(is_ip_range('fe80::1234%1%3%4', 6))
        self.assertFalse(is_ip_range('fe80%fe80%', 6))
        print('OK - test_invalid_ip_range_v6')

    def test_invalid_ip_range_v10(self):
        self.assertFalse(is_ip_range('abc', 10))
        self.assertFalse(is_ip_range('127.0.0.1/1', 10))
        self.assertFalse(is_ip_range('0.0.0.0/1', 10))
        self.assertFalse(is_ip_range('255.255.255.255/1', 10))
        print('OK - test_invalid_ip_range_v6')



import unittest
from pyvalidator import *

class TestIsFqdn(unittest.TestCase):

    def test_valid_fqdn(self):
        self.assertTrue(is_fqdn('domain.com'))
        self.assertTrue(is_fqdn('dom.plato'))
        self.assertTrue(is_fqdn('a.domain.co'))
        self.assertTrue(is_fqdn('foo--bar.com'))
        self.assertTrue(is_fqdn('xn--froschgrn-x9a.com'))
        self.assertTrue(is_fqdn('rebecca.blackfriday'))
        self.assertTrue(is_fqdn('1337.com'))
        print('OK - test_valid_fqdn')

    def test_invalid_fqdn(self):
        self.assertFalse(is_fqdn('abc'))
        self.assertFalse(is_fqdn('256.0.0.0'))
        self.assertFalse(is_fqdn('_.com'))
        self.assertFalse(is_fqdn('*.some.com'))
        self.assertFalse(is_fqdn('s!ome.com'))
        self.assertFalse(is_fqdn('domain.com/'))
        self.assertFalse(is_fqdn('/more.com'))
        self.assertFalse(is_fqdn('domain.com�'))
        self.assertFalse(is_fqdn('domain.co\u00A0m'))
        self.assertFalse(is_fqdn('domain.co\u1680m'))
        self.assertFalse(is_fqdn('domain.co\u2006m'))
        self.assertFalse(is_fqdn('domain.co\u2028m'))
        self.assertFalse(is_fqdn('domain.co\u2029m'))
        self.assertFalse(is_fqdn('domain.co\u202Fm'))
        self.assertFalse(is_fqdn('domain.co\u205Fm'))
        self.assertFalse(is_fqdn('domain.co\u3000m'))
        self.assertFalse(is_fqdn('domain.com\uDC00'))
        self.assertFalse(is_fqdn('domain.co\uEFFFm'))
        self.assertFalse(is_fqdn('domain.co\uFDDAm'))
        self.assertFalse(is_fqdn('domain.co\uFFF4m'))
        self.assertFalse(is_fqdn('domain.com©'))
        self.assertFalse(is_fqdn('example.0'))
        self.assertFalse(is_fqdn('192.168.0.9999'))
        self.assertFalse(is_fqdn('192.168.0'))
        print('OK - test_invalid_fqdn')

    def test_valid_fqdn_with_trailing_dot(self):
        self.assertTrue(is_fqdn('domain.com.', { "allow_trailing_dot": True }))
        print('OK - test_valid_fqdn_with_trailing_dot')

    def test_invalid_fqdn_with_not_required_tld(self):
        self.assertFalse(is_fqdn('example.0', { "require_tld": False }))
        self.assertFalse(is_fqdn('192.168.0', { "require_tld": False }))
        self.assertFalse(is_fqdn('192.168.0.9999', { "require_tld": False }))
        print('OK - test_invalid_fqdn_with_not_required_tld')

    def test_valid_fqdn_with_allowed_wildcard(self):
        self.assertTrue(is_fqdn('*.domain.com', { "allow_wildcard": True }))
        self.assertTrue(is_fqdn('*.global.domain.com', { "allow_wildcard": True }))
        print('OK - test_valid_fqdn_with_allowed_wildcard')

    def test_valid_fqdn_with_not_required_tld_but_allowed_numeric_tld(self):
        self.assertTrue(is_fqdn('example.0', { "require_tld": False, "allow_numeric_tld": True }))
        self.assertTrue(is_fqdn('192.168.0', { "require_tld": False, "allow_numeric_tld": True }))
        self.assertTrue(is_fqdn('192.168.0.9999', { "require_tld": False, "allow_numeric_tld": True }))
        print('OK - test_valid_fqdn_with_not_required_tld_but_allowed_numeric_tld')



import unittest
from pyvalidator import *

class TestIsDataUri(unittest.TestCase):

    def test_valid_data_uri(self):
        self.assertTrue(is_data_uri('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQAQMAAAAlPW0iAAAABlBMVEUAAAD///+l2Z/dAAAAM0lEQVR4nGP4/5/h/1+G/58ZDrAz3D/McH8yw83NDDeNGe4Ug9C9zwz3gVLMDA/A6P9/AFGGFyjOXZtQAAAAAElFTkSuQmCC'))
        self.assertTrue(is_data_uri('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAgAAAAIBAMAAAA2IaO4AAAAFVBMVEXk5OTn5+ft7e319fX29vb5+fn///++GUmVAAAALUlEQVQIHWNICnYLZnALTgpmMGYIFWYIZTA2ZFAzTTFlSDFVMwVyQhmAwsYMAKDaBy0axX/iAAAAAElFTkSuQmCC'))
        self.assertTrue(is_data_uri('   data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAgAAAAIBAMAAAA2IaO4AAAAFVBMVEXk5OTn5+ft7e319fX29vb5+fn///++GUmVAAAALUlEQVQIHWNICnYLZnALTgpmMGYIFWYIZTA2ZFAzTTFlSDFVMwVyQhmAwsYMAKDaBy0axX/iAAAAAElFTkSuQmCC   '))
        self.assertTrue(is_data_uri('data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%22100%22%20height%3D%22100%22%3E%3Crect%20fill%3D%22%2300B1FF%22%20width%3D%22100%22%20height%3D%22100%22%2F%3E%3C%2Fsvg%3E'))
        self.assertTrue(is_data_uri('data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMDAiIGhlaWdodD0iMTAwIj48cmVjdCBmaWxsPSIjMDBCMUZGIiB3aWR0aD0iMTAwIiBoZWlnaHQ9IjEwMCIvPjwvc3ZnPg=='))
        self.assertTrue(is_data_uri(' data:,Hello%2C%20World!'))
        self.assertTrue(is_data_uri(' data:,Hello World!'))
        self.assertTrue(is_data_uri(' data:text/plain;base64,SGVsbG8sIFdvcmxkIQ%3D%3D'))
        self.assertTrue(is_data_uri(' data:text/html,%3Ch1%3EHello%2C%20World!%3C%2Fh1%3E'))
        self.assertTrue(is_data_uri('data:,A%20brief%20note'))
        self.assertTrue(is_data_uri('data:text/html;charset=US-ASCII,%3Ch1%3EHello!%3C%2Fh1%3E'))
        print('OK - test_valid_data_uri')

    def test_invalid_data_uri(self):
        self.assertFalse(is_data_uri('dataxbase64'))
        self.assertFalse(is_data_uri('data:HelloWorld'))
        self.assertFalse(is_data_uri('data:,A%20brief%20invalid%20[note'))
        self.assertFalse(is_data_uri('file:text/plain;base64,SGVsbG8sIFdvcmxkIQ%3D%3D'))
        self.assertFalse(is_data_uri('data:text/html;charset=,%3Ch1%3EHello!%3C%2Fh1%3E'))
        self.assertFalse(is_data_uri('data:text/html;charset,%3Ch1%3EHello!%3C%2Fh1%3E'))
        self.assertFalse(is_data_uri('data:base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQAQMAAAAlPW0iAAAABlBMVEUAAAD///+l2Z/dAAAAM0lEQVR4nGP4/5/h/1+G/58ZDrAz3D/McH8yw83NDDeNGe4Ug9C9zwz3gVLMDA/A6P9/AFGGFyjOXZtQAAAAAElFTkSuQmCC'))
        self.assertFalse(is_data_uri(''))
        self.assertFalse(is_data_uri('http://wikipedia.org'))
        self.assertFalse(is_data_uri('base64'))
        self.assertFalse(is_data_uri('iVBORw0KGgoAAAANSUhEUgAAABAAAAAQAQMAAAAlPW0iAAAABlBMVEUAAAD///+l2Z/dAAAAM0lEQVR4nGP4/5/h/1+G/58ZDrAz3D/McH8yw83NDDeNGe4Ug9C9zwz3gVLMDA/A6P9/AFGGFyjOXZtQAAAAAElFTkSuQmCC'))
        print('OK - test_invalid_data_uri')



from typing import Literal

from .utils.Classes.RegEx import RegEx
from .utils.assert_string import assert_string
from .utils.slice import slice
from .utils.Classes.String import String
from .is_number import is_number

LENGTH_EAN_8 = 8
LENGTH_EAN_14 = 14
valid_ean_regex = RegEx("^(\d{8}|\d{13}|\d{14})$")

def get_position_weight_through_length_and_index(length: int, index: int) -> Literal[1, 3]:
    if length == LENGTH_EAN_8 or length == LENGTH_EAN_14:
        return 3 if (index % 2 == 0) else 1
    return 1 if (index % 2 == 0) else 3

def calculate_check_digit(ean: String) -> int:
    def iterator(char, index):
        return int(char) * get_position_weight_through_length_and_index(ean.length, index)

    def reducer(acc, partial_sum):
        return acc + partial_sum
    
    check_sum = ean.slice(0, -1).split().map(iterator).reduce(reducer, 0)

    remainder = 10 - (check_sum % 10)

    return remainder if remainder < 10 else 0

def is_ean(input: str) -> bool:
    input = assert_string(input)

    actual_check_digit = input.slice(-1)
    if not is_number(actual_check_digit):
        return False
    actual_check_digit = int(actual_check_digit)

    input_valid = bool(valid_ean_regex.match(input))

    digits_match = actual_check_digit == calculate_check_digit(input)
    
    return input_valid and digits_match




import unittest
from pyvalidator import *

class TestIsBase58(unittest.TestCase):

    def test_valid_base58(self):
        self.assertTrue(is_base58('BukQL'))
        self.assertTrue(is_base58('3KMUV89zab'))
        self.assertTrue(is_base58('91GHkLMNtyo98'))
        self.assertTrue(is_base58('YyjKm3H'))
        self.assertTrue(is_base58('Mkhss145TRFg'))
        self.assertTrue(is_base58('7678765677'))
        self.assertTrue(is_base58('abcodpq'))
        self.assertTrue(is_base58('AAVHJKLPY'))
        print('OK - test_valid_base58')

    def test_invalid_base58(self):
        self.assertFalse(is_base58('0OPLJH'))
        self.assertFalse(is_base58('IMKLP23'))
        self.assertFalse(is_base58('KLMOmk986'))
        self.assertFalse(is_base58('LL1l1985hG'))
        self.assertFalse(is_base58('*MP9K'))
        self.assertFalse(is_base58(')()(=9292929MKL'))
        print('OK - test_invalid_base58')



from .utils.Classes.RegEx import RegEx
from .utils.assert_string import assert_string

full_width_pattern = RegEx("[^\u0020-\u007E\uFF61-\uFF9F\uFFA0-\uFFDC\uFFE8-\uFFEE0-9a-zA-Z]")

def is_full_width(input: str) -> bool:
    input = assert_string(input)
    return full_width_pattern.match(input)



import unittest
from pyvalidator import *

class TestIsBoolean(unittest.TestCase):

    def test_valid_booleans(self):
        self.assertTrue(is_boolean('True'))
        self.assertTrue(is_boolean('False'))
        self.assertTrue(is_boolean('true'))
        self.assertTrue(is_boolean('false'))
        self.assertTrue(is_boolean('0'))
        self.assertTrue(is_boolean('1'))
        print('OK - test_valid_booleans')

    def test_invalid_booleans(self):
        self.assertFalse(is_boolean('1.0'))
        self.assertFalse(is_boolean('0.0'))
        self.assertFalse(is_boolean('true '))
        self.assertFalse(is_boolean('yes'))
        print('OK - test_invalid_booleans')

    def test_valid_loosly_booleans(self):
        self.assertTrue(is_boolean('true', { "loose": True }))
        self.assertTrue(is_boolean('True', { "loose": True }))
        self.assertTrue(is_boolean('TRUE', { "loose": True }))
        self.assertTrue(is_boolean('false', { "loose": True }))
        self.assertTrue(is_boolean('False', { "loose": True }))
        self.assertTrue(is_boolean('FALSE', { "loose": True }))
        self.assertTrue(is_boolean('0', { "loose": True }))
        self.assertTrue(is_boolean('1', { "loose": True }))
        self.assertTrue(is_boolean('yes', { "loose": True }))
        self.assertTrue(is_boolean('Yes', { "loose": True }))
        self.assertTrue(is_boolean('YES', { "loose": True }))
        self.assertTrue(is_boolean('no', { "loose": True }))
        self.assertTrue(is_boolean('No', { "loose": True }))
        self.assertTrue(is_boolean('NO', { "loose": True }))
        print('OK - test_valid_loosly_booleans')

    def test_invalid_loosly_booleans(self):
        self.assertFalse(is_boolean('1.0', { "loose": True }))
        self.assertFalse(is_boolean('0.0', { "loose": True }))
        self.assertFalse(is_boolean('true ', { "loose": True }))
        self.assertFalse(is_boolean(' false', { "loose": True }))
        print('OK - test_invalid_loosly_booleans')



from .utils.Classes.RegEx import RegEx
from .utils.assert_string import assert_string
from .utils.merge import merge
from .utils.math import grather_then_check, less_then_check

int_pattern = RegEx("^(?:[-+]?(?:0|[1-9][0-9]*))$")
int_leading_zero_pattern = RegEx("^[-+]?[0-9]+$")

__default_options = {
    "allow_leading_zeroes": True,
    "min": None,
    "max": None,
    "lt": None,
    "gt": None,
}

def is_int(input: str, options = __default_options) -> bool:
    input = assert_string(input)

    options = merge(options, __default_options)

    allow_leading_zeroes = options["allow_leading_zeroes"]

    picked_regex = int_pattern if not allow_leading_zeroes else int_leading_zero_pattern

    input_valid = bool(picked_regex.match(input))

    min_check_passed = grather_then_check(input, options["min"])
    max_check_passed = less_then_check(input, options["max"])
    lt_check_passed = grather_then_check(input, options["lt"])
    gt_check_passed = less_then_check(input, options["gt"])

    return input_valid and min_check_passed and max_check_passed and lt_check_passed and gt_check_passed



import unittest
from pyvalidator import *

class TestIsBase32(unittest.TestCase):

    def test_valid_base32(self):
        self.assertTrue(is_base32('ZG======'))
        self.assertTrue(is_base32('JBSQ===='))
        self.assertTrue(is_base32('JBSWY==='))
        self.assertTrue(is_base32('K5SWYY3PNVSSA5DPEBXG6ZA='))
        self.assertTrue(is_base32('K5SWYY3PNVSSA5DPEBXG6==='))
        print('OK - test_valid_base32')

    def test_invalid_base32(self):
        self.assertFalse(is_base32('12345'))
        self.assertFalse(is_base32(''))
        self.assertFalse(is_base32('ZG====='))
        self.assertFalse(is_base32('Zm=8JBSWY3DP'))
        self.assertFalse(is_base32('=m9vYg=='))
        self.assertFalse(is_base32('Zm9vYm/y===='))
        print('OK - test_invalid_base32')



import unittest
from pyvalidator import *

class TestIsStrongPassword(unittest.TestCase):
    options = {
        "min_length": 8,
        "min_lowercase": 1,
        "min_uppercase": 1,
        "min_numbers": 1,
        "min_symbols": 1,
    }

    def test_valid_stong_password(self):
        self.assertTrue(is_strong_password('%2%k{7BsL"M%Kd6e', self.options))
        self.assertTrue(is_strong_password('EXAMPLE of very long_password123!', self.options))
        self.assertTrue(is_strong_password('mxH_+2vs&54_+H3P', self.options))
        self.assertTrue(is_strong_password('+&DxJ=X7-4L8jRCD', self.options))
        self.assertTrue(is_strong_password('etV*p%Nr6w&H%FeF', self.options))
        print('OK - test_valid_stong_password')

    def test_invalid_stong_password(self):
        self.assertFalse(is_strong_password('', self.options))
        self.assertFalse(is_strong_password('password', self.options))
        self.assertFalse(is_strong_password('hunter2', self.options))
        self.assertFalse(is_strong_password('hello world', self.options))
        self.assertFalse(is_strong_password('passw0rd', self.options))
        self.assertFalse(is_strong_password('password!', self.options))
        self.assertFalse(is_strong_password('PASSWORD!', self.options))
        print('OK - test_invalid_stong_password')



from .utils.Classes.RegEx import RegEx
from .utils.assert_string import assert_string

hexadecimal_pattern = RegEx("^(0x|0h)?[0-9A-F]+$", "i")

def is_hexadecimal(input: str) -> bool:
    input = assert_string(input)

    return hexadecimal_pattern.match(input)
